app

package
v1.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 31, 2026 License: MIT Imports: 34 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	LoggingLevel      = "debug"
	Endpoint          = client.DefaultEndpoint()
	TCPListenAddress  = ""
	HTTPListenAddress = "127.0.0.1:7423"
	MaxRecords        = 5000
	Echo              = true
)
var (
	CLICommand *kong.Context
)
var SettingsRPCSocketPath = filepath.Join(filepath.Dir(client.DefaultSocketPath()), "devlogbusd-settings.sock")

Functions

func Setup

func Setup()

Types

type BuildInfoCommand

type BuildInfoCommand struct{}

func (*BuildInfoCommand) Run

func (b *BuildInfoCommand) Run() error

type BuildInfoCommandDef

type BuildInfoCommandDef struct {
	Version   VersionCommand   `cmd:"" help:"Show version"`
	Buildinfo BuildInfoCommand `cmd:"" hidden:"" help:"Show build information"`
}

type CLIConfig

type CLIConfig struct {
	app_settings.SettingsDef
	Commands
	Run     RunCommand `cmd:"" default:"1" help:"Run the DevLogBus broker in the foreground"`
	Service ServiceDef `cmd:"" help:"Service management commands" name:"systemd"`
	Verbose bool       `short:"v" help:"Enable verbose output to stdout on platforms that otherwise log to the service manager"`
}

type Commands

type Commands struct {
	BuildInfoCommandDef
	Completions CompletionsCommandDef `cmd:"" name:"autoCompletions" help:"Manage shell completions"`
}

type CompletionsCommandDef

type CompletionsCommandDef struct {
	Install   InstallCompletionsCommand   `cmd:"" help:"Persistently install shell completions for the detected shell"`
	Uninstall UninstallCompletionsCommand `cmd:"" help:"Remove previously installed shell completions for the detected shell"`
}

type InstallCompletionsCommand

type InstallCompletionsCommand struct {
	Shell   string `name:"shell" help:"Override the detected login shell (bash|zsh|fish)"`
	BinPath string `name:"bin-path" help:"Absolute path to the binary to register for shell completions"`
}

func (*InstallCompletionsCommand) Run

type InstallServiceCommand

type InstallServiceCommand struct{}

func (*InstallServiceCommand) Run

func (i *InstallServiceCommand) Run() error

type RemoveServiceCommand

type RemoveServiceCommand struct{}

func (*RemoveServiceCommand) Run

func (r *RemoveServiceCommand) Run() error

type RestartServiceCommand

type RestartServiceCommand struct{}

func (*RestartServiceCommand) Run

func (r *RestartServiceCommand) Run() error

type RunCommand

type RunCommand struct {
	Endpoint    string `` /* 134-byte string literal not displayed */
	TCPAddress  string `` /* 133-byte string literal not displayed */
	HTTPAddress string `name:"http" default:"${http_listen_address}" help:"HTTP listen address for browser clients; empty disables HTTP"`
	MaxRecords  int    `name:"max-records" default:"${max_records}" help:"Records to retain in memory"`
	Echo        bool   `name:"echo" default:"${echo}" help:"Print received records to stdout"`
}

func (*RunCommand) Run

func (c *RunCommand) Run() error

type ServiceDef

type ServiceDef struct {
	Install InstallServiceCommand `cmd:"" group:"Systemd" help:"Install the service"`
	Remove  RemoveServiceCommand  `cmd:"" group:"Systemd" help:"Remove the service"`
	Start   StartServiceCommand   `cmd:"" group:"Systemd" help:"Start the service"`
	Stop    StopServiceCommand    `cmd:"" group:"Systemd" help:"Stop the service"`
	Restart RestartServiceCommand `cmd:"" group:"Systemd" help:"Restart the service"`
	Status  ServiceStatusCommand  `cmd:"" group:"Systemd" help:"Show service status"`
}

type ServiceStatusCommand

type ServiceStatusCommand struct{}

func (*ServiceStatusCommand) Run

func (s *ServiceStatusCommand) Run() error

type StartServiceCommand

type StartServiceCommand struct{}

func (*StartServiceCommand) Run

func (s *StartServiceCommand) Run() error

type StopServiceCommand

type StopServiceCommand struct{}

func (*StopServiceCommand) Run

func (s *StopServiceCommand) Run() error

type UninstallCompletionsCommand

type UninstallCompletionsCommand struct {
	Shell string `name:"shell" help:"Override the detected login shell (bash|zsh|fish)"`
}

func (*UninstallCompletionsCommand) Run

type VersionCommand

type VersionCommand struct{}

func (*VersionCommand) Run

func (v *VersionCommand) Run() error

Directories

Path Synopsis

Jump to